Module: Mailblastr::Polls
- Defined in:
- lib/mailblastr/polls.rb
Overview
Read-only results of the in-email poll widget.
Class Method Summary collapse
-
.get(email_id) ⇒ Object
The aggregated answer breakdown for one email.
-
.list(params = {}) ⇒ Object
One summary row per email that has poll responses.
Class Method Details
.get(email_id) ⇒ Object
The aggregated answer breakdown for one email. GET /polls/:email_id
13 14 15 |
# File 'lib/mailblastr/polls.rb', line 13 def get(email_id) Client.request(:get, "/polls/#{Client.path_escape(email_id)}") end |
.list(params = {}) ⇒ Object
One summary row per email that has poll responses. GET /polls
8 9 10 |
# File 'lib/mailblastr/polls.rb', line 8 def list(params = {}) Client.request(:get, "/polls", query: Client.pagination(params)) end |